Class: Aws::SagemakerEdgeManager::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SagemakerEdgeManager::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-sagemakeredgemanager/client.rb
Overview
An API client for SagemakerEdgeManager. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::SagemakerEdgeManager::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#get_deployments(params = {}) ⇒ Types::GetDeploymentsResult
Use to get the active deployments from a device.
-
#get_device_registration(params = {}) ⇒ Types::GetDeviceRegistrationResult
Use to check if a device is registered with SageMaker Edge Manager.
-
#send_heartbeat(params = {}) ⇒ Struct
Use to get the current status of devices registered on SageMaker Edge Manager.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-sagemakeredgemanager/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
669 670 671 |
# File 'lib/aws-sdk-sagemakeredgemanager/client.rb', line 669 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
672 673 674 |
# File 'lib/aws-sdk-sagemakeredgemanager/client.rb', line 672 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 |
# File 'lib/aws-sdk-sagemakeredgemanager/client.rb', line 642 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SagemakerEdgeManager') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-sagemakeredgemanager' context[:gem_version] = '1.59.0' Seahorse::Client::Request.new(handlers, context) end |
#get_deployments(params = {}) ⇒ Types::GetDeploymentsResult
Use to get the active deployments from a device.
514 515 516 517 |
# File 'lib/aws-sdk-sagemakeredgemanager/client.rb', line 514 def get_deployments(params = {}, = {}) req = build_request(:get_deployments, params) req.send_request() end |
#get_device_registration(params = {}) ⇒ Types::GetDeviceRegistrationResult
Use to check if a device is registered with SageMaker Edge Manager.
549 550 551 552 |
# File 'lib/aws-sdk-sagemakeredgemanager/client.rb', line 549 def get_device_registration(params = {}, = {}) req = build_request(:get_device_registration, params) req.send_request() end |
#send_heartbeat(params = {}) ⇒ Struct
Use to get the current status of devices registered on SageMaker Edge Manager.
633 634 635 636 |
# File 'lib/aws-sdk-sagemakeredgemanager/client.rb', line 633 def send_heartbeat(params = {}, = {}) req = build_request(:send_heartbeat, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
662 663 664 |
# File 'lib/aws-sdk-sagemakeredgemanager/client.rb', line 662 def waiter_names [] end |