Class: Aws::SagemakerEdgeManager::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SagemakerEdgeManager::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-sagemakeredgemanager/client.rb
Overview
An API client for SagemakerEdgeManager. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::SagemakerEdgeManager::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#get_deployments(params = {}) ⇒ Types::GetDeploymentsResult
Use to get the active deployments from a device.
-
#get_device_registration(params = {}) ⇒ Types::GetDeviceRegistrationResult
Use to check if a device is registered with SageMaker Edge Manager.
-
#send_heartbeat(params = {}) ⇒ Struct
Use to get the current status of devices registered on SageMaker Edge Manager.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-sagemakeredgemanager/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
671 672 673 |
# File 'lib/aws-sdk-sagemakeredgemanager/client.rb', line 671 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
674 675 676 |
# File 'lib/aws-sdk-sagemakeredgemanager/client.rb', line 674 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 |
# File 'lib/aws-sdk-sagemakeredgemanager/client.rb', line 644 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SagemakerEdgeManager') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-sagemakeredgemanager' context[:gem_version] = '1.55.0' Seahorse::Client::Request.new(handlers, context) end |
#get_deployments(params = {}) ⇒ Types::GetDeploymentsResult
Use to get the active deployments from a device.
516 517 518 519 |
# File 'lib/aws-sdk-sagemakeredgemanager/client.rb', line 516 def get_deployments(params = {}, = {}) req = build_request(:get_deployments, params) req.send_request() end |
#get_device_registration(params = {}) ⇒ Types::GetDeviceRegistrationResult
Use to check if a device is registered with SageMaker Edge Manager.
551 552 553 554 |
# File 'lib/aws-sdk-sagemakeredgemanager/client.rb', line 551 def get_device_registration(params = {}, = {}) req = build_request(:get_device_registration, params) req.send_request() end |
#send_heartbeat(params = {}) ⇒ Struct
Use to get the current status of devices registered on SageMaker Edge Manager.
635 636 637 638 |
# File 'lib/aws-sdk-sagemakeredgemanager/client.rb', line 635 def send_heartbeat(params = {}, = {}) req = build_request(:send_heartbeat, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
664 665 666 |
# File 'lib/aws-sdk-sagemakeredgemanager/client.rb', line 664 def waiter_names [] end |